==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <source>compress...</source>
        <translation type="vanished">zkomprimovat…</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="74"/>
        <source>compress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="90"/>
        <source>uncompress to current path</source>
        <translation>rozbalit do stávajícího umístění</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="101"/>
        <source>uncompress to specific path...</source>
        <translation>rozbalit do zadaného umístění…</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">rozbalit do zadaného umístění</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">Rozšíření do Peony-Qt pro nabídku KArchive.</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">Rozšíření s nabídkou KArchive.</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>Rozšíření do Peony-Qt pro engrampa</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension.</source>
        <translation>Rozšíření s nabídkou engrampa.</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="66"/>
        <source>compress...</source>
        <translation>zkomprimovat…</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="82"/>
        <source>uncompress to current path</source>
        <translation>rozbalit do stávajícího umístění</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="93"/>
        <source>uncompress to specific path...</source>
        <translation>rozbalit do zadaného umístění…</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">rozbalit do zadaného umístění</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">Rozšíření do Peony-Qt pro nabídku KArchive.</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">Rozšíření s nabídkou KArchive.</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>Rozšíření do Peony-Qt pro engrampa</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension.</source>
        <translation>Rozšíření s nabídkou engrampa.</translation>
    </message>
</context>
</TS>
